==> Decorative%20Food-1.20.1-1.0.8-sources.jar: org/dfood/block/ModTotemBlock.java <==
package org.dfood.block;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_156;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_3726;
import net.minecraft.class_3965;
import net.minecraft.class_7923;
import net.minecraft.class_8567;
import net.minecraft.util.*;
import org.jetbrains.annotations.Nullable;

import java.util.Collections;
import java.util.List;

public class ModTotemBlock extends class_2248 {
    public static final class_2753 FACING = class_2741.field_12481;
    public static final class_2746 ENABLED = class_2746.method_11825("enabled");

    private static final class_265 SHAPE = class_2248.method_9541(4, 0, 4, 12, 6, 12);

    public ModTotemBlock(class_2251 settings) {
        super(settings);
        this.method_9590(this.method_9595().method_11664()
                .method_11657(FACING, class_2350.field_11043)
                .method_11657(ENABLED, false));
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return SHAPE;
    }

    @Override
    public @Nullable class_2680 method_9605(class_1750 ctx) {
        return this.method_9564()
                .method_11657(FACING, ctx.method_8042());
    }

    @Override
    public class_1269 method_9534(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_1268 hand, class_3965 hit) {
        if (!world.field_9236) {
            boolean currentState = state.method_11654(ENABLED);
            world.method_8652(pos, state.method_11657(ENABLED, !currentState), 3);
        }
        return class_1269.field_5812;
    }

    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    @Override
    public class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return state.method_26186(mirror.method_10345(state.method_11654(FACING)));
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING, ENABLED);
    }

    @Override
    public List<class_1799> method_9560(class_2680 state, class_8567.class_8568 builder) {
        return Collections.singletonList(new class_1799(this.method_8389()));
    }

    @Override
    public String method_9539() {
        return class_156.method_646("item", class_7923.field_41175.method_10221(this));
    }
}

==> Decorative%20Food-1.21.1-1.0.6-sources.jar: org/dfood/block/ModTotemBlock.java <==
package org.dfood.block;

import net.minecraft.class_1269;
import net.minecraft.class_156;
import net.minecraft.class_1657;
import net.minecraft.class_1750;
import net.minecraft.class_1799;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2415;
import net.minecraft.class_2470;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2746;
import net.minecraft.class_2753;
import net.minecraft.class_3726;
import net.minecraft.class_3965;
import net.minecraft.class_7923;
import net.minecraft.class_8567;
import net.minecraft.util.*;
import org.jetbrains.annotations.Nullable;

import java.util.Collections;
import java.util.List;

public class ModTotemBlock extends class_2248 {
    public static final class_2753 FACING = class_2741.field_12481;
    public static final class_2746 ENABLED = class_2746.method_11825("enabled");

    private static final class_265 SHAPE = class_2248.method_9541(4, 0, 4, 12, 6, 12);

    public ModTotemBlock(class_2251 settings) {
        super(settings);
        this.method_9590(this.method_9595().method_11664()
                .method_11657(FACING, class_2350.field_11043)
                .method_11657(ENABLED, false));
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 world, class_2338 pos, class_3726 context) {
        return SHAPE;
    }

    @Override
    public @Nullable class_2680 method_9605(class_1750 ctx) {
        return this.method_9564()
                .method_11657(FACING, ctx.method_8042());
    }

    @Override
    public class_1269 method_55766(class_2680 state, class_1937 world, class_2338 pos, class_1657 player, class_3965 hit) {
        if (!world.field_9236) {
            boolean currentState = state.method_11654(ENABLED);
            world.method_8652(pos, state.method_11657(ENABLED, !currentState), 3);
        }
        return class_1269.field_5812;
    }

    @Override
    public class_2680 method_9598(class_2680 state, class_2470 rotation) {
        return state.method_11657(FACING, rotation.method_10503(state.method_11654(FACING)));
    }

    @Override
    public class_2680 method_9569(class_2680 state, class_2415 mirror) {
        return state.method_26186(mirror.method_10345(state.method_11654(FACING)));
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FACING, ENABLED);
    }

    @Override
    public List<class_1799> method_9560(class_2680 state, class_8567.class_8568 builder) {
        return Collections.singletonList(new class_1799(this.method_8389()));
    }

    @Override
    public String method_9539() {
        return class_156.method_646("item", class_7923.field_41175.method_10221(this));
    }
}
